@@ -1,7 +1,7 @@
 /*
   License: LGPL
   Ref: Copied from this11/misc-2011/A1/wishart/Prog
-  $OpenXM: OpenXM/src/hgm/mh/src/rk.c,v 1.18 2016/03/02 01:09:36 takayama Exp $
+  $OpenXM: OpenXM/src/hgm/mh/src/rk.c,v 1.17 2016/03/02 00:27:02 takayama Exp $
 */
 #include <stdio.h>
 #include <stdlib.h>
@@ -45,7 +45,7 @@ static int mypower(int x,int n) {
   for (i=0; i<n; i++) a = a*x;
   return(a);
 }
-int mh_gopen_file() {
+int mh_gopen_file(void) {
   FILE *fp;
   char fname[1024];
   int i;
@@ -143,7 +143,7 @@ struct MH_RESULT mh_rkmain(double x0,double y0[],double xn)
     if (temp) mh_free(temp);
     if (ty) mh_free(ty);
     y = k1 = k2 = k3 = k4 = temp = ty = NULL;
-    initialized=0;
+    initialized=0;  result.x=0;/*dummy init to avoid warnings.*/
     return(result);
   }
   if (!initialized) {
